@@ -26,8 +26,8 @@ const links = [
         url: '/',
         title: 'Home'
     },{
-        url: '/cluster',
-        title: 'cluster'
+        url: '/namespaces',
+        title: 'Namespaces'
     },{
         url: 'https://kvrocks.apache.org',
         title: 'community',
